v1.0.0 - 08/25/2025

 	- First public release as an executable.

v1.1.0 - 10/28/2025

 	- Released as a Python Package on PyPi

 	- Added the ability to enter custom PDF equations.

v1.1.1 - 10/29/2025

 	-Fixed issues regarding faulty data upload.

v1.1.2 - 11/04/2025

 	-Fixed bug involving unenforced mass limitations while viewing prior monochromatic spectra

&nbsp;	-Tweaked plot labelling for increased legibility.

&nbsp;	-Added the ability to view previously generated histograms.



